#[non_exhaustive]pub enum Chain {
Hive,
HiveTestnet,
SteemLegacy,
}Expand description
A supported chain.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Hive
Hive, post-HF24. This is the default and the only one Hive callers want.
HiveTestnet
The Hive testnet.
SteemLegacy
Steem / pre-HF24 Hive, with the all-zero chain id.
Implementations
Sourceimpl Chain
impl Chain
Sourcepub fn properties(&self) -> ChainProperties
pub fn properties(&self) -> ChainProperties
The chain’s parameters.
Sourcepub fn asset(&self, symbol: &str) -> Result<ChainAsset>
pub fn asset(&self, symbol: &str) -> Result<ChainAsset>
Look up a native asset by its ticker or its NAI.